@@ -31,6 +31,7 @@ class UwEmailForwarding(models.Model):
 
 
 class Subscription(models.Model):
+    SUBS_OFFICE_356_PILOT = 59
     SUBS_CODE_KERBEROS = 60
     SUBS_CODE_2FA = 64
     SUBS_CODE_U_FORWARDING = 105
@@ -40,6 +41,8 @@ class Subscription(models.Model):
     SUBS_CODE_OFFICE_365_TEST = 234
     SUBS_CODE_PROJECT_SERVER_ONLINE_USER_ACCESS = 237
     SUBS_CODE_PROJECT_SERVER_ONLINE_USER_ACCESS_TEST = 238
+    SUBS_CODE_FUTURE_OFFICE_365 = 250
+    SUBS_CODE_OFFICE_365_ADDEE = 251
 
     STATUS_ACTIVE = 20
     STATUS_EXPIRED = 21
@@ -153,6 +156,27 @@ class Subscription(models.Model):
             "status_name", self.status_name)
 
 
+class SubscriptionPostResponse(models.Model):
+    uwnetid = models.SlugField(max_length=16,
+                               db_index=True,
+                               unique=True)
+    time_stamp = models.DateTimeField()
+    action = models.CharField(max_length=12)
+    result = models.CharField(max_length=16)
+    http_status = models.SmallIntegerField()
+    more_info = models.CharField(max_length=512)
+
+    def from_json(self, uwnetid, data):
+        self.uwnetid = uwnetid
+        self.time_stamp = data['timeStamp']
+        self.action = data['action']
+        self.result = data['result']
+        self.http_status = int(data['httpStatus'])
+        self.more_info = data['moreInfo']
+        self.query = data['query']
+        return self
+
+
 class SubscriptionPermit(models.Model):
     UNDERGRAD_C_CODE = 1
     GRAD_C_CODE = 2
@@ -272,6 +296,18 @@ class SubscriptionAction(models.Model):
 
 
 class Category(models.Model):
+    ALTID_SHARED_DEPARTMENTAL = 11
+    ALTID_SHARED_COURSE = 12
+    ALTID_SHARED_SAO = 21
+    ALTID_SHARED_CLINICAL_1 = 22
+    ALTID_SHARED_CLINICAL_2 = 23
+    ALTID_SHARED_FORWARDING = 24
+    ALTID_ADMIN_ADMINISTRATOR_EADM_WADM = 46
+    ALTID_SHARED_APPLICATION = 52
+    ALTID_SUPPORT_DEPARTMENTAL = 69
+    GOOGLE_SUITE_ENDORSEE = 234
+    OFFICE_365_ENDORSEE = 235
+
     STATUS_ACTIVE = 1
     STATUS_GRACE = 2
     STATUS_FORMER = 3
@@ -450,3 +486,42 @@ class UwPassword(models.Model):
 
     class Meta:
         db_table = "restclients_uwnetid_password"
+
+
+class Supported(models.Model):
+    name = models.SlugField(max_length=64,
+                            db_index=True,
+                            unique=True)
+    role = models.SlugField(max_length=16, null=True)
+    netid_type = models.SlugField(max_length=16, null=True)
+    status = models.SlugField(max_length=16, null=True)
+
+    def is_shared_netid(self):
+        return self.netid_type == 'shared'
+
+    def is_owner(self):
+        return self.role == 'owner' or self.role == 'owner-admin'
+
+    def is_admin(self):
+        return self.role == 'administrator' or self.role == 'owner-admin'
+
+    def from_json(self, data):
+        self.name = data['name']
+        self.role = data.get('role')
+        self.netid_type = data.get('netidType')
+        self.status = data.get('status')
+        return self
+
+    def json_data(self):
+        return {
+            'name': self.name,
+            'role': self.role,
+            'netidType': self.netid_type,
+            'status': self.status
+        }
+
+    def __str__(self):
+        return "%s" % self.json_data()
+
+    class Meta:
+        db_table = "restclients_uwnetid_supported"
